@@ -46,12 +46,15 @@ introspection_callable_call_with_return (IntrospectionCallable *callable)
   g_return_val_if_fail (INTROSPECTION_IS_CALLABLE (callable), NULL);
 
   iface = INTROSPECTION_CALLABLE_GET_IFACE (callable);
-  if (iface->call_with_return != NULL)
-    return iface->call_with_return (callable);
+  g_assert (iface->call_with_return != NULL);
 
-  return NULL;
+  return iface->call_with_return (callable);
 }
 
+/**
+ * introspection_callable_call_no_args:
+ * @callable:
+ */
 void
 introspection_callable_call_no_args (IntrospectionCallable *callable)
 {
@@ -60,8 +63,9 @@ introspection_callable_call_no_args (IntrospectionCallable *callable)
   g_return_if_fail (INTROSPECTION_IS_CALLABLE (callable));
 
   iface = INTROSPECTION_CALLABLE_GET_IFACE (callable);
-  if (iface->call_no_args != NULL)
-    iface->call_no_args (callable);
+  g_assert (iface->call_no_args != NULL);
+
+  iface->call_no_args (callable);
 }
 
 /**
@@ -78,8 +82,9 @@ introspection_callable_call_single_arg (IntrospectionCallable *callable,
   g_return_if_fail (INTROSPECTION_IS_CALLABLE (callable));
 
   iface = INTROSPECTION_CALLABLE_GET_IFACE (callable);
-  if (iface->call_single_arg != NULL)
-    iface->call_single_arg (callable, called);
+  g_assert (iface->call_single_arg != NULL);
+
+  iface->call_single_arg (callable, called);
 }
 
 /**
@@ -100,6 +105,7 @@ introspection_callable_call_multi_args (IntrospectionCallable *callable,
   g_return_if_fail (INTROSPECTION_IS_CALLABLE (callable));
 
   iface = INTROSPECTION_CALLABLE_GET_IFACE (callable);
-  if (iface->call_multi_args != NULL)
-    iface->call_multi_args (callable, in, out, inout);
+  g_assert (iface->call_multi_args != NULL);
+
+  iface->call_multi_args (callable, in, out, inout);
 }
